@@ -626,7 +626,12 @@ class CfnWorkGroup(
             typing.Union[bool, _IResolvable_9ceae33e]
         ] = None,
         state: typing.Optional[str] = None,
-        tags: typing.Optional["TagsProperty"] = None,
+        tags: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
+            ]
+        ] = None,
         work_group_configuration: typing.Optional[
             typing.Union["WorkGroupConfigurationProperty", _IResolvable_9ceae33e]
         ] = None,
@@ -1067,45 +1072,6 @@ class CfnWorkGroup(
                 k + "=" + repr(v) for k, v in self._values.items()
             )
 
-    @jsii.data_type(
-        jsii_type="monocdk-experiment.aws_athena.CfnWorkGroup.TagsProperty",
-        jsii_struct_bases=[],
-        name_mapping={"tags": "tags"},
-    )
-    class TagsProperty:
-        def __init__(
-            self, *, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None
-        ) -> None:
-            """
-            :param tags: ``CfnWorkGroup.TagsProperty.Tags``.
-
-            see
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-tags.html
-            """
-            self._values = {}
-            if tags is not None:
-                self._values["tags"] = tags
-
-        @builtins.property
-        def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
-            """``CfnWorkGroup.TagsProperty.Tags``.
-
-            see
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-tags.html#cfn-athena-workgroup-tags-tags
-            """
-            return self._values.get("tags")
-
-        def __eq__(self, rhs) -> bool:
-            return isinstance(rhs, self.__class__) and rhs._values == self._values
-
-        def __ne__(self, rhs) -> bool:
-            return not (rhs == self)
-
-        def __repr__(self) -> str:
-            return "TagsProperty(%s)" % ", ".join(
-                k + "=" + repr(v) for k, v in self._values.items()
-            )
-
     @jsii.data_type(
         jsii_type="monocdk-experiment.aws_athena.CfnWorkGroup.WorkGroupConfigurationProperty",
         jsii_struct_bases=[],
@@ -1407,7 +1373,12 @@ class CfnWorkGroupProps:
             typing.Union[bool, _IResolvable_9ceae33e]
         ] = None,
         state: typing.Optional[str] = None,
-        tags: typing.Optional["CfnWorkGroup.TagsProperty"] = None,
+        tags: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
+            ]
+        ] = None,
         work_group_configuration: typing.Optional[
             typing.Union[
                 "CfnWorkGroup.WorkGroupConfigurationProperty", _IResolvable_9ceae33e
@@ -1433,8 +1404,6 @@ class CfnWorkGroupProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html
         """
-        if isinstance(tags, dict):
-            tags = CfnWorkGroup.TagsProperty(**tags)
         self._values = {
             "name": name,
         }
@@ -1492,7 +1461,14 @@ class CfnWorkGroupProps:
         return self._values.get("state")
 
     @builtins.property
-    def tags(self) -> typing.Optional["CfnWorkGroup.TagsProperty"]:
+    def tags(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
+        ]
+    ]:
         """``AWS::Athena::WorkGroup.Tags``.
 
         see
