@@ -46,9 +46,15 @@ class CfnDomain(
         advanced_options: typing.Optional[
             typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]
         ] = None,
+        advanced_security_options: typing.Optional[
+            typing.Union["AdvancedSecurityOptionsInputProperty", _IResolvable_9ceae33e]
+        ] = None,
         cognito_options: typing.Optional[
             typing.Union["CognitoOptionsProperty", _IResolvable_9ceae33e]
         ] = None,
+        domain_endpoint_options: typing.Optional[
+            typing.Union["DomainEndpointOptionsProperty", _IResolvable_9ceae33e]
+        ] = None,
         domain_name: typing.Optional[str] = None,
         ebs_options: typing.Optional[
             typing.Union["EBSOptionsProperty", _IResolvable_9ceae33e]
@@ -86,7 +92,9 @@ class CfnDomain(
         :param id: - scoped id of the resource.
         :param access_policies: ``AWS::Elasticsearch::Domain.AccessPolicies``.
         :param advanced_options: ``AWS::Elasticsearch::Domain.AdvancedOptions``.
+        :param advanced_security_options: ``AWS::Elasticsearch::Domain.AdvancedSecurityOptions``.
         :param cognito_options: ``AWS::Elasticsearch::Domain.CognitoOptions``.
+        :param domain_endpoint_options: ``AWS::Elasticsearch::Domain.DomainEndpointOptions``.
         :param domain_name: ``AWS::Elasticsearch::Domain.DomainName``.
         :param ebs_options: ``AWS::Elasticsearch::Domain.EBSOptions``.
         :param elasticsearch_cluster_config: ``AWS::Elasticsearch::Domain.ElasticsearchClusterConfig``.
@@ -101,7 +109,9 @@ class CfnDomain(
         props = CfnDomainProps(
             access_policies=access_policies,
             advanced_options=advanced_options,
+            advanced_security_options=advanced_security_options,
             cognito_options=cognito_options,
+            domain_endpoint_options=domain_endpoint_options,
             domain_name=domain_name,
             ebs_options=ebs_options,
             elasticsearch_cluster_config=elasticsearch_cluster_config,
@@ -238,6 +248,29 @@ class CfnDomain(
     ) -> None:
         jsii.set(self, "advancedOptions", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="advancedSecurityOptions")
+    def advanced_security_options(
+        self,
+    ) -> typing.Optional[
+        typing.Union["AdvancedSecurityOptionsInputProperty", _IResolvable_9ceae33e]
+    ]:
+        """``AWS::Elasticsearch::Domain.AdvancedSecurityOptions``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticsearch-domain.html#cfn-elasticsearch-domain-advancedsecurityoptions
+        """
+        return jsii.get(self, "advancedSecurityOptions")
+
+    @advanced_security_options.setter
+    def advanced_security_options(
+        self,
+        value: typing.Optional[
+            typing.Union["AdvancedSecurityOptionsInputProperty", _IResolvable_9ceae33e]
+        ],
+    ) -> None:
+        jsii.set(self, "advancedSecurityOptions", value)
+
     @builtins.property
     @jsii.member(jsii_name="cognitoOptions")
     def cognito_options(
@@ -259,6 +292,29 @@ class CfnDomain(
     ) -> None:
         jsii.set(self, "cognitoOptions", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="domainEndpointOptions")
+    def domain_endpoint_options(
+        self,
+    ) -> typing.Optional[
+        typing.Union["DomainEndpointOptionsProperty", _IResolvable_9ceae33e]
+    ]:
+        """``AWS::Elasticsearch::Domain.DomainEndpointOptions``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticsearch-domain.html#cfn-elasticsearch-domain-domainendpointoptions
+        """
+        return jsii.get(self, "domainEndpointOptions")
+
+    @domain_endpoint_options.setter
+    def domain_endpoint_options(
+        self,
+        value: typing.Optional[
+            typing.Union["DomainEndpointOptionsProperty", _IResolvable_9ceae33e]
+        ],
+    ) -> None:
+        jsii.set(self, "domainEndpointOptions", value)
+
     @builtins.property
     @jsii.member(jsii_name="domainName")
     def domain_name(self) -> typing.Optional[str]:
@@ -455,6 +511,91 @@ class CfnDomain(
     ) -> None:
         jsii.set(self, "vpcOptions", value)
 
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_elasticsearch.CfnDomain.AdvancedSecurityOptionsInputProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "enabled": "enabled",
+            "internal_user_database_enabled": "internalUserDatabaseEnabled",
+            "master_user_options": "masterUserOptions",
+        },
+    )
+    class AdvancedSecurityOptionsInputProperty:
+        def __init__(
+            self,
+            *,
+            enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            internal_user_database_enabled: typing.Optional[
+                typing.Union[bool, _IResolvable_9ceae33e]
+            ] = None,
+            master_user_options: typing.Optional[
+                typing.Union[
+                    "CfnDomain.MasterUserOptionsProperty", _IResolvable_9ceae33e
+                ]
+            ] = None,
+        ) -> None:
+            """
+            :param enabled: ``CfnDomain.AdvancedSecurityOptionsInputProperty.Enabled``.
+            :param internal_user_database_enabled: ``CfnDomain.AdvancedSecurityOptionsInputProperty.InternalUserDatabaseEnabled``.
+            :param master_user_options: ``CfnDomain.AdvancedSecurityOptionsInputProperty.MasterUserOptions``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticsearch-domain-advancedsecurityoptionsinput.html
+            """
+            self._values = {}
+            if enabled is not None:
+                self._values["enabled"] = enabled
+            if internal_user_database_enabled is not None:
+                self._values[
+                    "internal_user_database_enabled"
+                ] = internal_user_database_enabled
+            if master_user_options is not None:
+                self._values["master_user_options"] = master_user_options
+
+        @builtins.property
+        def enabled(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+            """``CfnDomain.AdvancedSecurityOptionsInputProperty.Enabled``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticsearch-domain-advancedsecurityoptionsinput.html#cfn-elasticsearch-domain-advancedsecurityoptionsinput-enabled
+            """
+            return self._values.get("enabled")
+
+        @builtins.property
+        def internal_user_database_enabled(
+            self,
+        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+            """``CfnDomain.AdvancedSecurityOptionsInputProperty.InternalUserDatabaseEnabled``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticsearch-domain-advancedsecurityoptionsinput.html#cfn-elasticsearch-domain-advancedsecurityoptionsinput-internaluserdatabaseenabled
+            """
+            return self._values.get("internal_user_database_enabled")
+
+        @builtins.property
+        def master_user_options(
+            self,
+        ) -> typing.Optional[
+            typing.Union["CfnDomain.MasterUserOptionsProperty", _IResolvable_9ceae33e]
+        ]:
+            """``CfnDomain.AdvancedSecurityOptionsInputProperty.MasterUserOptions``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticsearch-domain-advancedsecurityoptionsinput.html#cfn-elasticsearch-domain-advancedsecurityoptionsinput-masteruseroptions
+            """
+            return self._values.get("master_user_options")
+
+        def __eq__(self, rhs) -> bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs) -> bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "AdvancedSecurityOptionsInputProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
     @jsii.data_type(
         jsii_type="monocdk-experiment.aws_elasticsearch.CfnDomain.CognitoOptionsProperty",
         jsii_struct_bases=[],
@@ -540,6 +681,67 @@ class CfnDomain(
                 k + "=" + repr(v) for k, v in self._values.items()
             )
 
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_elasticsearch.CfnDomain.DomainEndpointOptionsProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "enforce_https": "enforceHttps",
+            "tls_security_policy": "tlsSecurityPolicy",
+        },
+    )
+    class DomainEndpointOptionsProperty:
+        def __init__(
+            self,
+            *,
+            enforce_https: typing.Optional[
+                typing.Union[bool, _IResolvable_9ceae33e]
+            ] = None,
+            tls_security_policy: typing.Optional[str] = None,
+        ) -> None:
+            """
+            :param enforce_https: ``CfnDomain.DomainEndpointOptionsProperty.EnforceHTTPS``.
+            :param tls_security_policy: ``CfnDomain.DomainEndpointOptionsProperty.TLSSecurityPolicy``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticsearch-domain-domainendpointoptions.html
+            """
+            self._values = {}
+            if enforce_https is not None:
+                self._values["enforce_https"] = enforce_https
+            if tls_security_policy is not None:
+                self._values["tls_security_policy"] = tls_security_policy
+
+        @builtins.property
+        def enforce_https(
+            self,
+        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+            """``CfnDomain.DomainEndpointOptionsProperty.EnforceHTTPS``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticsearch-domain-domainendpointoptions.html#cfn-elasticsearch-domain-domainendpointoptions-enforcehttps
+            """
+            return self._values.get("enforce_https")
+
+        @builtins.property
+        def tls_security_policy(self) -> typing.Optional[str]:
+            """``CfnDomain.DomainEndpointOptionsProperty.TLSSecurityPolicy``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticsearch-domain-domainendpointoptions.html#cfn-elasticsearch-domain-domainendpointoptions-tlssecuritypolicy
+            """
+            return self._values.get("tls_security_policy")
+
+        def __eq__(self, rhs) -> bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs) -> bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "DomainEndpointOptionsProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
     @jsii.data_type(
         jsii_type="monocdk-experiment.aws_elasticsearch.CfnDomain.EBSOptionsProperty",
         jsii_struct_bases=[],
@@ -885,6 +1087,77 @@ class CfnDomain(
                 k + "=" + repr(v) for k, v in self._values.items()
             )
 
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_elasticsearch.CfnDomain.MasterUserOptionsProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "master_user_arn": "masterUserArn",
+            "master_user_name": "masterUserName",
+            "master_user_password": "masterUserPassword",
+        },
+    )
+    class MasterUserOptionsProperty:
+        def __init__(
+            self,
+            *,
+            master_user_arn: typing.Optional[str] = None,
+            master_user_name: typing.Optional[str] = None,
+            master_user_password: typing.Optional[str] = None,
+        ) -> None:
+            """
+            :param master_user_arn: ``CfnDomain.MasterUserOptionsProperty.MasterUserARN``.
+            :param master_user_name: ``CfnDomain.MasterUserOptionsProperty.MasterUserName``.
+            :param master_user_password: ``CfnDomain.MasterUserOptionsProperty.MasterUserPassword``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticsearch-domain-masteruseroptions.html
+            """
+            self._values = {}
+            if master_user_arn is not None:
+                self._values["master_user_arn"] = master_user_arn
+            if master_user_name is not None:
+                self._values["master_user_name"] = master_user_name
+            if master_user_password is not None:
+                self._values["master_user_password"] = master_user_password
+
+        @builtins.property
+        def master_user_arn(self) -> typing.Optional[str]:
+            """``CfnDomain.MasterUserOptionsProperty.MasterUserARN``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticsearch-domain-masteruseroptions.html#cfn-elasticsearch-domain-masteruseroptions-masteruserarn
+            """
+            return self._values.get("master_user_arn")
+
+        @builtins.property
+        def master_user_name(self) -> typing.Optional[str]:
+            """``CfnDomain.MasterUserOptionsProperty.MasterUserName``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticsearch-domain-masteruseroptions.html#cfn-elasticsearch-domain-masteruseroptions-masterusername
+            """
+            return self._values.get("master_user_name")
+
+        @builtins.property
+        def master_user_password(self) -> typing.Optional[str]:
+            """``CfnDomain.MasterUserOptionsProperty.MasterUserPassword``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticsearch-domain-masteruseroptions.html#cfn-elasticsearch-domain-masteruseroptions-masteruserpassword
+            """
+            return self._values.get("master_user_password")
+
+        def __eq__(self, rhs) -> bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs) -> bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "MasterUserOptionsProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
     @jsii.data_type(
         jsii_type="monocdk-experiment.aws_elasticsearch.CfnDomain.NodeToNodeEncryptionOptionsProperty",
         jsii_struct_bases=[],
@@ -1070,7 +1343,9 @@ class CfnDomain(
     name_mapping={
         "access_policies": "accessPolicies",
         "advanced_options": "advancedOptions",
+        "advanced_security_options": "advancedSecurityOptions",
         "cognito_options": "cognitoOptions",
+        "domain_endpoint_options": "domainEndpointOptions",
         "domain_name": "domainName",
         "ebs_options": "ebsOptions",
         "elasticsearch_cluster_config": "elasticsearchClusterConfig",
@@ -1091,9 +1366,19 @@ class CfnDomainProps:
         advanced_options: typing.Optional[
             typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]
         ] = None,
+        advanced_security_options: typing.Optional[
+            typing.Union[
+                "CfnDomain.AdvancedSecurityOptionsInputProperty", _IResolvable_9ceae33e
+            ]
+        ] = None,
         cognito_options: typing.Optional[
             typing.Union["CfnDomain.CognitoOptionsProperty", _IResolvable_9ceae33e]
         ] = None,
+        domain_endpoint_options: typing.Optional[
+            typing.Union[
+                "CfnDomain.DomainEndpointOptionsProperty", _IResolvable_9ceae33e
+            ]
+        ] = None,
         domain_name: typing.Optional[str] = None,
         ebs_options: typing.Optional[
             typing.Union["CfnDomain.EBSOptionsProperty", _IResolvable_9ceae33e]
@@ -1137,7 +1422,9 @@ class CfnDomainProps:
 
         :param access_policies: ``AWS::Elasticsearch::Domain.AccessPolicies``.
         :param advanced_options: ``AWS::Elasticsearch::Domain.AdvancedOptions``.
+        :param advanced_security_options: ``AWS::Elasticsearch::Domain.AdvancedSecurityOptions``.
         :param cognito_options: ``AWS::Elasticsearch::Domain.CognitoOptions``.
+        :param domain_endpoint_options: ``AWS::Elasticsearch::Domain.DomainEndpointOptions``.
         :param domain_name: ``AWS::Elasticsearch::Domain.DomainName``.
         :param ebs_options: ``AWS::Elasticsearch::Domain.EBSOptions``.
         :param elasticsearch_cluster_config: ``AWS::Elasticsearch::Domain.ElasticsearchClusterConfig``.
@@ -1157,8 +1444,12 @@ class CfnDomainProps:
             self._values["access_policies"] = access_policies
         if advanced_options is not None:
             self._values["advanced_options"] = advanced_options
+        if advanced_security_options is not None:
+            self._values["advanced_security_options"] = advanced_security_options
         if cognito_options is not None:
             self._values["cognito_options"] = cognito_options
+        if domain_endpoint_options is not None:
+            self._values["domain_endpoint_options"] = domain_endpoint_options
         if domain_name is not None:
             self._values["domain_name"] = domain_name
         if ebs_options is not None:
@@ -1202,6 +1493,21 @@ class CfnDomainProps:
         """
         return self._values.get("advanced_options")
 
+    @builtins.property
+    def advanced_security_options(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            "CfnDomain.AdvancedSecurityOptionsInputProperty", _IResolvable_9ceae33e
+        ]
+    ]:
+        """``AWS::Elasticsearch::Domain.AdvancedSecurityOptions``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticsearch-domain.html#cfn-elasticsearch-domain-advancedsecurityoptions
+        """
+        return self._values.get("advanced_security_options")
+
     @builtins.property
     def cognito_options(
         self,
@@ -1215,6 +1521,19 @@ class CfnDomainProps:
         """
         return self._values.get("cognito_options")
 
+    @builtins.property
+    def domain_endpoint_options(
+        self,
+    ) -> typing.Optional[
+        typing.Union["CfnDomain.DomainEndpointOptionsProperty", _IResolvable_9ceae33e]
+    ]:
+        """``AWS::Elasticsearch::Domain.DomainEndpointOptions``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticsearch-domain.html#cfn-elasticsearch-domain-domainendpointoptions
+        """
+        return self._values.get("domain_endpoint_options")
+
     @builtins.property
     def domain_name(self) -> typing.Optional[str]:
         """``AWS::Elasticsearch::Domain.DomainName``.
