@@ -10,11 +10,24 @@ import publication
 
 from .._jsii import *
 
-from .. import (CfnResource as _CfnResource_7760e8e4, Construct as _Construct_f50a3f53, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, IInspectable as _IInspectable_051e6ed8, IResolvable as _IResolvable_9ceae33e, CfnTag as _CfnTag_b4661f1a)
+from .. import (
+    CfnResource as _CfnResource_7760e8e4,
+    Construct as _Construct_f50a3f53,
+    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
+    ICfnFinder as _ICfnFinder_3b168f30,
+    TreeInspector as _TreeInspector_154f5999,
+    IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+    CfnTag as _CfnTag_b4661f1a,
+)
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnAssessmentTarget(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_inspector.CfnAssessmentTarget"):
+class CfnAssessmentTarget(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_inspector.CfnAssessmentTarget",
+):
     """A CloudFormation ``AWS::Inspector::AssessmentTarget``.
 
     see
@@ -22,7 +35,15 @@ class CfnAssessmentTarget(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
     cloudformationResource:
     :cloudformationResource:: AWS::Inspector::AssessmentTarget
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, assessment_target_name: typing.Optional[str]=None, resource_group_arn: typing.Optional[str]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        assessment_target_name: typing.Optional[str] = None,
+        resource_group_arn: typing.Optional[str] = None,
+    ) -> None:
         """Create a new ``AWS::Inspector::AssessmentTarget``.
 
         :param scope: - scope in which this resource is defined.
@@ -30,13 +51,23 @@ class CfnAssessmentTarget(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
         :param assessment_target_name: ``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
         :param resource_group_arn: ``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
         """
-        props = CfnAssessmentTargetProps(assessment_target_name=assessment_target_name, resource_group_arn=resource_group_arn)
+        props = CfnAssessmentTargetProps(
+            assessment_target_name=assessment_target_name,
+            resource_group_arn=resource_group_arn,
+        )
 
         jsii.create(CfnAssessmentTarget, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnAssessmentTarget":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnAssessmentTarget":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -51,7 +82,9 @@ class CfnAssessmentTarget(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -65,7 +98,9 @@ class CfnAssessmentTarget(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -120,9 +155,21 @@ class CfnAssessmentTarget(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
         jsii.set(self, "resourceGroupArn", value)
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_inspector.CfnAssessmentTargetProps", jsii_struct_bases=[], name_mapping={'assessment_target_name': 'assessmentTargetName', 'resource_group_arn': 'resourceGroupArn'})
-class CfnAssessmentTargetProps():
-    def __init__(self, *, assessment_target_name: typing.Optional[str]=None, resource_group_arn: typing.Optional[str]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_inspector.CfnAssessmentTargetProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "assessment_target_name": "assessmentTargetName",
+        "resource_group_arn": "resourceGroupArn",
+    },
+)
+class CfnAssessmentTargetProps:
+    def __init__(
+        self,
+        *,
+        assessment_target_name: typing.Optional[str] = None,
+        resource_group_arn: typing.Optional[str] = None,
+    ) -> None:
         """Properties for defining a ``AWS::Inspector::AssessmentTarget``.
 
         :param assessment_target_name: ``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
@@ -131,10 +178,11 @@ class CfnAssessmentTargetProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html
         """
-        self._values = {
-        }
-        if assessment_target_name is not None: self._values["assessment_target_name"] = assessment_target_name
-        if resource_group_arn is not None: self._values["resource_group_arn"] = resource_group_arn
+        self._values = {}
+        if assessment_target_name is not None:
+            self._values["assessment_target_name"] = assessment_target_name
+        if resource_group_arn is not None:
+            self._values["resource_group_arn"] = resource_group_arn
 
     @builtins.property
     def assessment_target_name(self) -> typing.Optional[str]:
@@ -143,7 +191,7 @@ class CfnAssessmentTargetProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-assessmenttargetname
         """
-        return self._values.get('assessment_target_name')
+        return self._values.get("assessment_target_name")
 
     @builtins.property
     def resource_group_arn(self) -> typing.Optional[str]:
@@ -152,7 +200,7 @@ class CfnAssessmentTargetProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-resourcegrouparn
         """
-        return self._values.get('resource_group_arn')
+        return self._values.get("resource_group_arn")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -161,11 +209,17 @@ class CfnAssessmentTargetProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnAssessmentTargetProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnAssessmentTargetProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnAssessmentTemplate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_inspector.CfnAssessmentTemplate"):
+class CfnAssessmentTemplate(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_inspector.CfnAssessmentTemplate",
+):
     """A CloudFormation ``AWS::Inspector::AssessmentTemplate``.
 
     see
@@ -173,7 +227,23 @@ class CfnAssessmentTemplate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii
     cloudformationResource:
     :cloudformationResource:: AWS::Inspector::AssessmentTemplate
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, assessment_target_arn: str, duration_in_seconds: jsii.Number, rules_package_arns: typing.List[str], assessment_template_name: typing.Optional[str]=None, user_attributes_for_findings: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        assessment_target_arn: str,
+        duration_in_seconds: jsii.Number,
+        rules_package_arns: typing.List[str],
+        assessment_template_name: typing.Optional[str] = None,
+        user_attributes_for_findings: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
+            ]
+        ] = None,
+    ) -> None:
         """Create a new ``AWS::Inspector::AssessmentTemplate``.
 
         :param scope: - scope in which this resource is defined.
@@ -184,13 +254,26 @@ class CfnAssessmentTemplate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii
         :param assessment_template_name: ``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
         :param user_attributes_for_findings: ``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
         """
-        props = CfnAssessmentTemplateProps(assessment_target_arn=assessment_target_arn, duration_in_seconds=duration_in_seconds, rules_package_arns=rules_package_arns, assessment_template_name=assessment_template_name, user_attributes_for_findings=user_attributes_for_findings)
+        props = CfnAssessmentTemplateProps(
+            assessment_target_arn=assessment_target_arn,
+            duration_in_seconds=duration_in_seconds,
+            rules_package_arns=rules_package_arns,
+            assessment_template_name=assessment_template_name,
+            user_attributes_for_findings=user_attributes_for_findings,
+        )
 
         jsii.create(CfnAssessmentTemplate, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnAssessmentTemplate":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnAssessmentTemplate":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -205,7 +288,9 @@ class CfnAssessmentTemplate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -219,7 +304,9 @@ class CfnAssessmentTemplate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -303,7 +390,14 @@ class CfnAssessmentTemplate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii
 
     @builtins.property
     @jsii.member(jsii_name="userAttributesForFindings")
-    def user_attributes_for_findings(self) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]]:
+    def user_attributes_for_findings(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
+        ]
+    ]:
         """``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
         see
@@ -312,13 +406,44 @@ class CfnAssessmentTemplate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii
         return jsii.get(self, "userAttributesForFindings")
 
     @user_attributes_for_findings.setter
-    def user_attributes_for_findings(self, value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]]) -> None:
+    def user_attributes_for_findings(
+        self,
+        value: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
+            ]
+        ],
+    ) -> None:
         jsii.set(self, "userAttributesForFindings", value)
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_inspector.CfnAssessmentTemplateProps", jsii_struct_bases=[], name_mapping={'assessment_target_arn': 'assessmentTargetArn', 'duration_in_seconds': 'durationInSeconds', 'rules_package_arns': 'rulesPackageArns', 'assessment_template_name': 'assessmentTemplateName', 'user_attributes_for_findings': 'userAttributesForFindings'})
-class CfnAssessmentTemplateProps():
-    def __init__(self, *, assessment_target_arn: str, duration_in_seconds: jsii.Number, rules_package_arns: typing.List[str], assessment_template_name: typing.Optional[str]=None, user_attributes_for_findings: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_inspector.CfnAssessmentTemplateProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "assessment_target_arn": "assessmentTargetArn",
+        "duration_in_seconds": "durationInSeconds",
+        "rules_package_arns": "rulesPackageArns",
+        "assessment_template_name": "assessmentTemplateName",
+        "user_attributes_for_findings": "userAttributesForFindings",
+    },
+)
+class CfnAssessmentTemplateProps:
+    def __init__(
+        self,
+        *,
+        assessment_target_arn: str,
+        duration_in_seconds: jsii.Number,
+        rules_package_arns: typing.List[str],
+        assessment_template_name: typing.Optional[str] = None,
+        user_attributes_for_findings: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
+            ]
+        ] = None,
+    ) -> None:
         """Properties for defining a ``AWS::Inspector::AssessmentTemplate``.
 
         :param assessment_target_arn: ``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
@@ -331,12 +456,14 @@ class CfnAssessmentTemplateProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html
         """
         self._values = {
-            'assessment_target_arn': assessment_target_arn,
-            'duration_in_seconds': duration_in_seconds,
-            'rules_package_arns': rules_package_arns,
+            "assessment_target_arn": assessment_target_arn,
+            "duration_in_seconds": duration_in_seconds,
+            "rules_package_arns": rules_package_arns,
         }
-        if assessment_template_name is not None: self._values["assessment_template_name"] = assessment_template_name
-        if user_attributes_for_findings is not None: self._values["user_attributes_for_findings"] = user_attributes_for_findings
+        if assessment_template_name is not None:
+            self._values["assessment_template_name"] = assessment_template_name
+        if user_attributes_for_findings is not None:
+            self._values["user_attributes_for_findings"] = user_attributes_for_findings
 
     @builtins.property
     def assessment_target_arn(self) -> str:
@@ -345,7 +472,7 @@ class CfnAssessmentTemplateProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttargetarn
         """
-        return self._values.get('assessment_target_arn')
+        return self._values.get("assessment_target_arn")
 
     @builtins.property
     def duration_in_seconds(self) -> jsii.Number:
@@ -354,7 +481,7 @@ class CfnAssessmentTemplateProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-durationinseconds
         """
-        return self._values.get('duration_in_seconds')
+        return self._values.get("duration_in_seconds")
 
     @builtins.property
     def rules_package_arns(self) -> typing.List[str]:
@@ -363,7 +490,7 @@ class CfnAssessmentTemplateProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-rulespackagearns
         """
-        return self._values.get('rules_package_arns')
+        return self._values.get("rules_package_arns")
 
     @builtins.property
     def assessment_template_name(self) -> typing.Optional[str]:
@@ -372,16 +499,23 @@ class CfnAssessmentTemplateProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttemplatename
         """
-        return self._values.get('assessment_template_name')
+        return self._values.get("assessment_template_name")
 
     @builtins.property
-    def user_attributes_for_findings(self) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]]:
+    def user_attributes_for_findings(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
+        ]
+    ]:
         """``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-userattributesforfindings
         """
-        return self._values.get('user_attributes_for_findings')
+        return self._values.get("user_attributes_for_findings")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -390,11 +524,17 @@ class CfnAssessmentTemplateProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnAssessmentTemplateProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnAssessmentTemplateProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnResourceGroup(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_inspector.CfnResourceGroup"):
+class CfnResourceGroup(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_inspector.CfnResourceGroup",
+):
     """A CloudFormation ``AWS::Inspector::ResourceGroup``.
 
     see
@@ -402,7 +542,17 @@ class CfnResourceGroup(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type
     cloudformationResource:
     :cloudformationResource:: AWS::Inspector::ResourceGroup
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, resource_group_tags: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        resource_group_tags: typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
+        ],
+    ) -> None:
         """Create a new ``AWS::Inspector::ResourceGroup``.
 
         :param scope: - scope in which this resource is defined.
@@ -415,7 +565,14 @@ class CfnResourceGroup(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnResourceGroup":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnResourceGroup":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -430,7 +587,9 @@ class CfnResourceGroup(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -444,7 +603,9 @@ class CfnResourceGroup(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -472,7 +633,12 @@ class CfnResourceGroup(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type
 
     @builtins.property
     @jsii.member(jsii_name="resourceGroupTags")
-    def resource_group_tags(self) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]:
+    def resource_group_tags(
+        self,
+    ) -> typing.Union[
+        _IResolvable_9ceae33e,
+        typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
+    ]:
         """``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
         see
@@ -481,13 +647,30 @@ class CfnResourceGroup(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type
         return jsii.get(self, "resourceGroupTags")
 
     @resource_group_tags.setter
-    def resource_group_tags(self, value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]) -> None:
+    def resource_group_tags(
+        self,
+        value: typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
+        ],
+    ) -> None:
         jsii.set(self, "resourceGroupTags", value)
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_inspector.CfnResourceGroupProps", jsii_struct_bases=[], name_mapping={'resource_group_tags': 'resourceGroupTags'})
-class CfnResourceGroupProps():
-    def __init__(self, *, resource_group_tags: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_inspector.CfnResourceGroupProps",
+    jsii_struct_bases=[],
+    name_mapping={"resource_group_tags": "resourceGroupTags"},
+)
+class CfnResourceGroupProps:
+    def __init__(
+        self,
+        *,
+        resource_group_tags: typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
+        ],
+    ) -> None:
         """Properties for defining a ``AWS::Inspector::ResourceGroup``.
 
         :param resource_group_tags: ``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
@@ -496,17 +679,22 @@ class CfnResourceGroupProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html
         """
         self._values = {
-            'resource_group_tags': resource_group_tags,
+            "resource_group_tags": resource_group_tags,
         }
 
     @builtins.property
-    def resource_group_tags(self) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]:
+    def resource_group_tags(
+        self,
+    ) -> typing.Union[
+        _IResolvable_9ceae33e,
+        typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
+    ]:
         """``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html#cfn-inspector-resourcegroup-resourcegrouptags
         """
-        return self._values.get('resource_group_tags')
+        return self._values.get("resource_group_tags")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -515,7 +703,9 @@ class CfnResourceGroupProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnResourceGroupProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnResourceGroupProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
