@@ -116,6 +116,7 @@ class NodejsFunction(
         scope: _Construct_f50a3f53,
         id: str,
         *,
+        aws_sdk_connection_reuse: typing.Optional[bool] = None,
         entry: typing.Optional[str] = None,
         handler: typing.Optional[str] = None,
         runtime: typing.Optional[_Runtime_8b970b80] = None,
@@ -162,6 +163,7 @@ class NodejsFunction(
         """
         :param scope: -
         :param id: -
+        :param aws_sdk_connection_reuse: Whether to automatically reuse TCP connections when working with the AWS SDK for JavaScript. This sets the ``AWS_NODEJS_CONNECTION_REUSE_ENABLED`` environment variable to ``1``. Default: true
         :param entry: Path to the entry file (JavaScript or TypeScript). Default: - Derived from the name of the defining file and the construct's id. If the ``NodejsFunction`` is defined in ``stack.ts`` with ``my-handler`` as id (``new NodejsFunction(this, 'my-handler')``), the construct will look at ``stack.my-handler.ts`` and ``stack.my-handler.js``.
         :param handler: The name of the exported handler in the entry file. Default: handler
         :param runtime: The runtime environment. Only runtimes of the Node.js family are supported. Default: - ``NODEJS_12_X`` if ``process.versions.node`` >= '12.0.0', ``NODEJS_10_X`` otherwise.
@@ -207,6 +209,7 @@ class NodejsFunction(
         :stability: experimental
         """
         props = NodejsFunctionProps(
+            aws_sdk_connection_reuse=aws_sdk_connection_reuse,
             entry=entry,
             handler=handler,
             runtime=runtime,
@@ -708,6 +711,7 @@ class ParcelOptions(ParcelBaseOptions):
         "parcel_version": "parcelVersion",
         "project_root": "projectRoot",
         "source_maps": "sourceMaps",
+        "aws_sdk_connection_reuse": "awsSdkConnectionReuse",
         "entry": "entry",
         "handler": "handler",
         "runtime": "runtime",
@@ -756,6 +760,7 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
         parcel_version: typing.Optional[str] = None,
         project_root: typing.Optional[str] = None,
         source_maps: typing.Optional[bool] = None,
+        aws_sdk_connection_reuse: typing.Optional[bool] = None,
         entry: typing.Optional[str] = None,
         handler: typing.Optional[str] = None,
         runtime: typing.Optional[_Runtime_8b970b80] = None,
@@ -799,6 +804,7 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
         :param parcel_version: The version of Parcel to use. Default: - 2.0.0-beta.1
         :param project_root: The root of the project. This will be used as the source for the volume mounted in the Docker container. If you specify this prop, ensure that this path includes ``entry`` and any module/dependencies used by your function otherwise bundling will not be possible. Default: - the closest path containing a .git folder
         :param source_maps: Whether to include source maps when bundling. Default: false
+        :param aws_sdk_connection_reuse: Whether to automatically reuse TCP connections when working with the AWS SDK for JavaScript. This sets the ``AWS_NODEJS_CONNECTION_REUSE_ENABLED`` environment variable to ``1``. Default: true
         :param entry: Path to the entry file (JavaScript or TypeScript). Default: - Derived from the name of the defining file and the construct's id. If the ``NodejsFunction`` is defined in ``stack.ts`` with ``my-handler`` as id (``new NodejsFunction(this, 'my-handler')``), the construct will look at ``stack.my-handler.ts`` and ``stack.my-handler.js``.
         :param handler: The name of the exported handler in the entry file. Default: handler
         :param runtime: The runtime environment. Only runtimes of the Node.js family are supported. Default: - ``NODEJS_12_X`` if ``process.versions.node`` >= '12.0.0', ``NODEJS_10_X`` otherwise.
@@ -893,6 +899,8 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
             self._values["project_root"] = project_root
         if source_maps is not None:
             self._values["source_maps"] = source_maps
+        if aws_sdk_connection_reuse is not None:
+            self._values["aws_sdk_connection_reuse"] = aws_sdk_connection_reuse
         if entry is not None:
             self._values["entry"] = entry
         if handler is not None:
@@ -1438,6 +1446,23 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
         """
         return self._values.get("source_maps")
 
+    @builtins.property
+    def aws_sdk_connection_reuse(self) -> typing.Optional[bool]:
+        """Whether to automatically reuse TCP connections when working with the AWS SDK for JavaScript.
+
+        This sets the ``AWS_NODEJS_CONNECTION_REUSE_ENABLED`` environment variable
+        to ``1``.
+
+        default
+        :default: true
+
+        see
+        :see: https://docs.aws.amazon.com/sdk-for-javascript/v2/developer-guide/node-reusing-connections.html
+        stability
+        :stability: experimental
+        """
+        return self._values.get("aws_sdk_connection_reuse")
+
     @builtins.property
     def entry(self) -> typing.Optional[str]:
         """Path to the entry file (JavaScript or TypeScript).
