@@ -10,20 +10,48 @@ import publication
 
 from .._jsii import *
 
-from .. import (Construct as _Construct_f50a3f53, CfnResource as _CfnResource_7760e8e4, IAsset as _IAsset_a3f13b15, AssetOptions as _AssetOptions_b07b0eef, AssetHashType as _AssetHashType_16f7047a, BundlingOptions as _BundlingOptions_0cab5223)
-from ..assets import (CopyOptions as _CopyOptions_65085089, FollowMode as _FollowMode_f74e7125)
-from ..aws_iam import (IGrantable as _IGrantable_0fcfc53a)
-from ..aws_s3 import (IBucket as _IBucket_25bad983)
+from .. import (
+    Construct as _Construct_f50a3f53,
+    CfnResource as _CfnResource_7760e8e4,
+    IAsset as _IAsset_a3f13b15,
+    AssetOptions as _AssetOptions_b07b0eef,
+    AssetHashType as _AssetHashType_16f7047a,
+    BundlingOptions as _BundlingOptions_0cab5223,
+)
+from ..assets import (
+    CopyOptions as _CopyOptions_65085089,
+    FollowMode as _FollowMode_f74e7125,
+)
+from ..aws_iam import IGrantable as _IGrantable_0fcfc53a
+from ..aws_s3 import IBucket as _IBucket_25bad983
 
 
 @jsii.implements(_IAsset_a3f13b15)
-class Asset(_Construct_f50a3f53, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_s3_assets.Asset"):
+class Asset(
+    _Construct_f50a3f53,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_s3_assets.Asset",
+):
     """An asset represents a local file or directory, which is automatically uploaded to S3 and then can be referenced within a CDK application.
 
     stability
     :stability: experimental
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, path: str, readers: typing.Optional[typing.List[_IGrantable_0fcfc53a]]=None, source_hash: typing.Optional[str]=None, exclude: typing.Optional[typing.List[str]]=None, follow: typing.Optional[_FollowMode_f74e7125]=None, asset_hash: typing.Optional[str]=None, asset_hash_type: typing.Optional[_AssetHashType_16f7047a]=None, bundling: typing.Optional[_BundlingOptions_0cab5223]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        path: str,
+        readers: typing.Optional[typing.List[_IGrantable_0fcfc53a]] = None,
+        source_hash: typing.Optional[str] = None,
+        exclude: typing.Optional[typing.List[str]] = None,
+        follow: typing.Optional[_FollowMode_f74e7125] = None,
+        asset_hash: typing.Optional[str] = None,
+        asset_hash_type: typing.Optional[_AssetHashType_16f7047a] = None,
+        bundling: typing.Optional[_BundlingOptions_0cab5223] = None,
+    ) -> None:
         """
         :param scope: -
         :param id: -
@@ -39,12 +67,23 @@ class Asset(_Construct_f50a3f53, metaclass=jsii.JSIIMeta, jsii_type="monocdk-exp
         stability
         :stability: experimental
         """
-        props = AssetProps(path=path, readers=readers, source_hash=source_hash, exclude=exclude, follow=follow, asset_hash=asset_hash, asset_hash_type=asset_hash_type, bundling=bundling)
+        props = AssetProps(
+            path=path,
+            readers=readers,
+            source_hash=source_hash,
+            exclude=exclude,
+            follow=follow,
+            asset_hash=asset_hash,
+            asset_hash_type=asset_hash_type,
+            bundling=bundling,
+        )
 
         jsii.create(Asset, self, [scope, id, props])
 
     @jsii.member(jsii_name="addResourceMetadata")
-    def add_resource_metadata(self, resource: _CfnResource_7760e8e4, resource_property: str) -> None:
+    def add_resource_metadata(
+        self, resource: _CfnResource_7760e8e4, resource_property: str
+    ) -> None:
         """Adds CloudFormation template metadata to the specified resource with information that indicates which resource property is mapped to this local asset.
 
         This can be used by tools such as SAM CLI to provide local
@@ -202,9 +241,31 @@ class Asset(_Construct_f50a3f53, metaclass=jsii.JSIIMeta, jsii_type="monocdk-exp
         return jsii.get(self, "sourceHash")
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_s3_assets.AssetOptions", jsii_struct_bases=[_CopyOptions_65085089, _AssetOptions_b07b0eef], name_mapping={'exclude': 'exclude', 'follow': 'follow', 'asset_hash': 'assetHash', 'asset_hash_type': 'assetHashType', 'bundling': 'bundling', 'readers': 'readers', 'source_hash': 'sourceHash'})
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_s3_assets.AssetOptions",
+    jsii_struct_bases=[_CopyOptions_65085089, _AssetOptions_b07b0eef],
+    name_mapping={
+        "exclude": "exclude",
+        "follow": "follow",
+        "asset_hash": "assetHash",
+        "asset_hash_type": "assetHashType",
+        "bundling": "bundling",
+        "readers": "readers",
+        "source_hash": "sourceHash",
+    },
+)
 class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
-    def __init__(self, *, exclude: typing.Optional[typing.List[str]]=None, follow: typing.Optional[_FollowMode_f74e7125]=None, asset_hash: typing.Optional[str]=None, asset_hash_type: typing.Optional[_AssetHashType_16f7047a]=None, bundling: typing.Optional[_BundlingOptions_0cab5223]=None, readers: typing.Optional[typing.List[_IGrantable_0fcfc53a]]=None, source_hash: typing.Optional[str]=None) -> None:
+    def __init__(
+        self,
+        *,
+        exclude: typing.Optional[typing.List[str]] = None,
+        follow: typing.Optional[_FollowMode_f74e7125] = None,
+        asset_hash: typing.Optional[str] = None,
+        asset_hash_type: typing.Optional[_AssetHashType_16f7047a] = None,
+        bundling: typing.Optional[_BundlingOptions_0cab5223] = None,
+        readers: typing.Optional[typing.List[_IGrantable_0fcfc53a]] = None,
+        source_hash: typing.Optional[str] = None,
+    ) -> None:
         """
         :param exclude: Glob patterns to exclude from the copy. Default: nothing is excluded
         :param follow: A strategy for how to handle symlinks. Default: Never
@@ -217,16 +278,23 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         stability
         :stability: experimental
         """
-        if isinstance(bundling, dict): bundling = _BundlingOptions_0cab5223(**bundling)
-        self._values = {
-        }
-        if exclude is not None: self._values["exclude"] = exclude
-        if follow is not None: self._values["follow"] = follow
-        if asset_hash is not None: self._values["asset_hash"] = asset_hash
-        if asset_hash_type is not None: self._values["asset_hash_type"] = asset_hash_type
-        if bundling is not None: self._values["bundling"] = bundling
-        if readers is not None: self._values["readers"] = readers
-        if source_hash is not None: self._values["source_hash"] = source_hash
+        if isinstance(bundling, dict):
+            bundling = _BundlingOptions_0cab5223(**bundling)
+        self._values = {}
+        if exclude is not None:
+            self._values["exclude"] = exclude
+        if follow is not None:
+            self._values["follow"] = follow
+        if asset_hash is not None:
+            self._values["asset_hash"] = asset_hash
+        if asset_hash_type is not None:
+            self._values["asset_hash_type"] = asset_hash_type
+        if bundling is not None:
+            self._values["bundling"] = bundling
+        if readers is not None:
+            self._values["readers"] = readers
+        if source_hash is not None:
+            self._values["source_hash"] = source_hash
 
     @builtins.property
     def exclude(self) -> typing.Optional[typing.List[str]]:
@@ -238,7 +306,7 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         stability
         :stability: deprecated
         """
-        return self._values.get('exclude')
+        return self._values.get("exclude")
 
     @builtins.property
     def follow(self) -> typing.Optional[_FollowMode_f74e7125]:
@@ -250,7 +318,7 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         stability
         :stability: deprecated
         """
-        return self._values.get('follow')
+        return self._values.get("follow")
 
     @builtins.property
     def asset_hash(self) -> typing.Optional[str]:
@@ -273,7 +341,7 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         stability
         :stability: experimental
         """
-        return self._values.get('asset_hash')
+        return self._values.get("asset_hash")
 
     @builtins.property
     def asset_hash_type(self) -> typing.Optional[_AssetHashType_16f7047a]:
@@ -291,7 +359,7 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         stability
         :stability: experimental
         """
-        return self._values.get('asset_hash_type')
+        return self._values.get("asset_hash_type")
 
     @builtins.property
     def bundling(self) -> typing.Optional[_BundlingOptions_0cab5223]:
@@ -311,7 +379,7 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         stability
         :stability: experimental
         """
-        return self._values.get('bundling')
+        return self._values.get("bundling")
 
     @builtins.property
     def readers(self) -> typing.Optional[typing.List[_IGrantable_0fcfc53a]]:
@@ -325,7 +393,7 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         stability
         :stability: experimental
         """
-        return self._values.get('readers')
+        return self._values.get("readers")
 
     @builtins.property
     def source_hash(self) -> typing.Optional[str]:
@@ -353,7 +421,7 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         stability
         :stability: deprecated
         """
-        return self._values.get('source_hash')
+        return self._values.get("source_hash")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -362,12 +430,38 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'AssetOptions(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "AssetOptions(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_s3_assets.AssetProps", jsii_struct_bases=[AssetOptions], name_mapping={'exclude': 'exclude', 'follow': 'follow', 'asset_hash': 'assetHash', 'asset_hash_type': 'assetHashType', 'bundling': 'bundling', 'readers': 'readers', 'source_hash': 'sourceHash', 'path': 'path'})
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_s3_assets.AssetProps",
+    jsii_struct_bases=[AssetOptions],
+    name_mapping={
+        "exclude": "exclude",
+        "follow": "follow",
+        "asset_hash": "assetHash",
+        "asset_hash_type": "assetHashType",
+        "bundling": "bundling",
+        "readers": "readers",
+        "source_hash": "sourceHash",
+        "path": "path",
+    },
+)
 class AssetProps(AssetOptions):
-    def __init__(self, *, exclude: typing.Optional[typing.List[str]]=None, follow: typing.Optional[_FollowMode_f74e7125]=None, asset_hash: typing.Optional[str]=None, asset_hash_type: typing.Optional[_AssetHashType_16f7047a]=None, bundling: typing.Optional[_BundlingOptions_0cab5223]=None, readers: typing.Optional[typing.List[_IGrantable_0fcfc53a]]=None, source_hash: typing.Optional[str]=None, path: str) -> None:
+    def __init__(
+        self,
+        *,
+        exclude: typing.Optional[typing.List[str]] = None,
+        follow: typing.Optional[_FollowMode_f74e7125] = None,
+        asset_hash: typing.Optional[str] = None,
+        asset_hash_type: typing.Optional[_AssetHashType_16f7047a] = None,
+        bundling: typing.Optional[_BundlingOptions_0cab5223] = None,
+        readers: typing.Optional[typing.List[_IGrantable_0fcfc53a]] = None,
+        source_hash: typing.Optional[str] = None,
+        path: str,
+    ) -> None:
         """
         :param exclude: Glob patterns to exclude from the copy. Default: nothing is excluded
         :param follow: A strategy for how to handle symlinks. Default: Never
@@ -381,17 +475,25 @@ class AssetProps(AssetOptions):
         stability
         :stability: experimental
         """
-        if isinstance(bundling, dict): bundling = _BundlingOptions_0cab5223(**bundling)
+        if isinstance(bundling, dict):
+            bundling = _BundlingOptions_0cab5223(**bundling)
         self._values = {
-            'path': path,
+            "path": path,
         }
-        if exclude is not None: self._values["exclude"] = exclude
-        if follow is not None: self._values["follow"] = follow
-        if asset_hash is not None: self._values["asset_hash"] = asset_hash
-        if asset_hash_type is not None: self._values["asset_hash_type"] = asset_hash_type
-        if bundling is not None: self._values["bundling"] = bundling
-        if readers is not None: self._values["readers"] = readers
-        if source_hash is not None: self._values["source_hash"] = source_hash
+        if exclude is not None:
+            self._values["exclude"] = exclude
+        if follow is not None:
+            self._values["follow"] = follow
+        if asset_hash is not None:
+            self._values["asset_hash"] = asset_hash
+        if asset_hash_type is not None:
+            self._values["asset_hash_type"] = asset_hash_type
+        if bundling is not None:
+            self._values["bundling"] = bundling
+        if readers is not None:
+            self._values["readers"] = readers
+        if source_hash is not None:
+            self._values["source_hash"] = source_hash
 
     @builtins.property
     def exclude(self) -> typing.Optional[typing.List[str]]:
@@ -403,7 +505,7 @@ class AssetProps(AssetOptions):
         stability
         :stability: deprecated
         """
-        return self._values.get('exclude')
+        return self._values.get("exclude")
 
     @builtins.property
     def follow(self) -> typing.Optional[_FollowMode_f74e7125]:
@@ -415,7 +517,7 @@ class AssetProps(AssetOptions):
         stability
         :stability: deprecated
         """
-        return self._values.get('follow')
+        return self._values.get("follow")
 
     @builtins.property
     def asset_hash(self) -> typing.Optional[str]:
@@ -438,7 +540,7 @@ class AssetProps(AssetOptions):
         stability
         :stability: experimental
         """
-        return self._values.get('asset_hash')
+        return self._values.get("asset_hash")
 
     @builtins.property
     def asset_hash_type(self) -> typing.Optional[_AssetHashType_16f7047a]:
@@ -456,7 +558,7 @@ class AssetProps(AssetOptions):
         stability
         :stability: experimental
         """
-        return self._values.get('asset_hash_type')
+        return self._values.get("asset_hash_type")
 
     @builtins.property
     def bundling(self) -> typing.Optional[_BundlingOptions_0cab5223]:
@@ -476,7 +578,7 @@ class AssetProps(AssetOptions):
         stability
         :stability: experimental
         """
-        return self._values.get('bundling')
+        return self._values.get("bundling")
 
     @builtins.property
     def readers(self) -> typing.Optional[typing.List[_IGrantable_0fcfc53a]]:
@@ -490,7 +592,7 @@ class AssetProps(AssetOptions):
         stability
         :stability: experimental
         """
-        return self._values.get('readers')
+        return self._values.get("readers")
 
     @builtins.property
     def source_hash(self) -> typing.Optional[str]:
@@ -518,7 +620,7 @@ class AssetProps(AssetOptions):
         stability
         :stability: deprecated
         """
-        return self._values.get('source_hash')
+        return self._values.get("source_hash")
 
     @builtins.property
     def path(self) -> str:
@@ -532,7 +634,7 @@ class AssetProps(AssetOptions):
         stability
         :stability: experimental
         """
-        return self._values.get('path')
+        return self._values.get("path")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -541,7 +643,9 @@ class AssetProps(AssetOptions):
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'AssetProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "AssetProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
